package org.apache.ojb.broker;

/* Copyright 2002-2004 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.ojb.broker.core.PersistenceBrokerFactoryFactory;
import org.apache.ojb.broker.util.configuration.Configurator;
import org.apache.ojb.broker.util.configuration.impl.OjbConfigurator;
import org.apache.ojb.broker.metadata.MetadataManager;

/**
 * Convenience factory class that produces {@link PersistenceBroker} instances.
 *
 * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryFactory
 * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryIF
 * @author Thomas Mahler
 * @version $Id: PersistenceBrokerFactory.java,v 1.23 2004/04/04 23:53:30 brianm Exp $
 */
public class PersistenceBrokerFactory
{
    /**
     * Returns the {@link org.apache.ojb.broker.util.configuration.Configurator}
     * object.
     *
     * @return the configurator
     */
    public static Configurator getConfigurator()
    {
        return OjbConfigurator.getInstance();
    }

    /**
     * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryIF#setDefaultKey
     */
    public static void setDefaultKey(PBKey key)
    {
        MetadataManager.getInstance().setDefaultPBKey(key);
    }

    /**
     * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryIF#getDefaultKey
     */
    public static PBKey getDefaultKey()
    {
        return MetadataManager.getInstance().getDefaultPBKey();
    }

    /**
     * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryIF#defaultPersistenceBroker
     */
    public static PersistenceBroker defaultPersistenceBroker() throws PBFactoryException
    {
        return PersistenceBrokerFactoryFactory.instance().
                defaultPersistenceBroker();
    }

    /**
     * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryIF#createPersistenceBroker(java.lang.String, java.lang.String, java.lang.String)
     */
    public static PersistenceBroker createPersistenceBroker(String jcdAlias,
                                                            String user, String password)
            throws PBFactoryException
    {
        return PersistenceBrokerFactoryFactory.instance().
                createPersistenceBroker(jcdAlias, user, password);
    }

    /**
     * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryIF#createPersistenceBroker(org.apache.ojb.broker.PBKey)
     */
    public static PersistenceBroker createPersistenceBroker(PBKey key)
            throws PBFactoryException
    {
        return PersistenceBrokerFactoryFactory.instance().createPersistenceBroker(key);
    }

    /**
     * @see org.apache.ojb.broker.core.PersistenceBrokerFactoryIF#releaseAllInstances
     */
    public static void releaseAllInstances()
    {
        PersistenceBrokerFactoryFactory.instance().releaseAllInstances();
    }
}
